#!/bin/sh
modules=$*
#--------------------------------------------------------------------------#
if test -z "$modules" ; then
  echo "Usage $0 module [module ...]"
  exit 1
fi
for module in $modules ; do
  case $module in
    bonoboui)
      pkgname="libbonoboui-2.0"
      includes="#include <libbonoboui.h>"
      ;;
    gnomeui)
      pkgname="libgnomeui-2.0"
      includes="#include <libgnomeui/libgnomeui.h>"
      ;;
    gtk)
      pkgname=gtk+-2.0
      includes="#include <gtk/gtk.h>"
      ;;
    *)
      echo "Unsupported module $module"
      continue
      ;;
  esac
#--------------------------------------------------------------------------#
  includedir=`pkg-config $pkgname --variable=includedir`$includeprefix
  typesfile=$module.types
  export CFLAGS=`pkg-config $pkgname --cflags`
  export LDFLAGS=`pkg-config $pkgname --libs`

  ### generate types file from headers ###
  echo "Creating $typesfile from headers (might take a while)"
  echo "$includes" > $typesfile
  typelist=`echo "$includes" | cpp $CFLAGS | grep "^GType.*_get_type" | sed "s/^GType\W*\(\w\+\)\W.*$/\1/"`
  if test "$typelist" ; then
    for type in $typelist ; do
      echo "$type" >> $typesfile
    done
  fi
  #for filename in $includedir/*.h ; do
  #  #echo -n "Checking `basename $filename`..."
  #  echo -n "."
  #  typelist=`cat $filename | grep "^GType.*_get_type" | sed "s/^GType\W*\(\w\+\)\W.*$/\1/"`
  #  if test "$typelist" ; then
  #    for type in $typelist ; do
  #      #echo "found $type()"
  #      echo "$type" >> $typesfile
  #    done
  #  #else
  #  #  echo "no type found"
  #  fi
  #done
  #echo "done"
  #for file in $dir/*.h ; do
  #  echo $file
  #  cat $file|sed "s/struct _\(*.\)Class/\1/"
  #  class=`cat $file|grep -E "^typedef struct _\w+Class.*"|sed "s/.*_\(\w*\)Class.*/\1/"`
  #  if test "$class" ; then
  #    echo "<widget>"
  #    echo "  <class>$class</class>"
  #    echo "</widget>"
  #  fi
  #  exit
  #done

  ### run gtk-doc to generate various files ###
  #gtkdoc-scan --module=$module --source-dir=$widgetdir
  #gtkdoc-scanobj --module=$module
  gtkdoc-scangobj --module=$module

  ### generate args.widgetdb from args file ###
  filename=$module.args
  echo "Creating $filename.widgetdb from $filename"
  cat $filename | awk -f args2xml.awk > $filename.xml
  xsltproc args2widgetdb.xslt $filename.xml > $filename.widgetdb

  ### generate hierarchy.widgetdb from hierarchy file ###
  filename=$module.hierarchy
  echo "Creating $filename.widgetdb from $filename"
  cat $filename | awk -f hierarchy2widgetdb.awk > $filename.widgetdb

  ### delete all the files we don't need ###
  #echo "Cleaning up"
  #rm -f $module.args $module.args.xml $module.hierarchy $module.interfaces
  #rm -f $module.prerequisites $module.signals $module.types
done
