/*
 * glade2c - convert glade user interfaces to C source
 *
 * Copyright (C) 2009 Magnus Bergman
 *
 * Author: Magnus Bergman <fabel@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "../autoconf.h"

#include "debug.h"
#include "glade2c.h"
#include "project.h"
#include "read-glade.h"
#include "widgetdb.h"
#include "write-source.h"

void print_version(){
    g_print(PACKAGE " version " VERSION ".\n");
}

int main(int argc,char** argv){
    if(!read_config(&argc,&argv)){
        DEBUG_p("fatal error readning configuration");
        return 1;
    }

    read_widgetdb();

    DEBUG_p("base directory  : %s",project.basedir);
    DEBUG_p("project filename: %s",project.gladep_filename);
    DEBUG_p("glade filename  : %s",project.glade_filename);
    DEBUG_p("main source file: %s/%s/%s",project.basedir,project.source_directory,project.interface_source_file);
    DEBUG_p("main header file: %s/%s/%s",project.basedir,project.source_directory,project.interface_header_file);

    project.callback_list = g_hash_table_new(g_str_hash,g_str_equal);

    /* Create the source directory */
    {
        char* srcdir;
        srcdir = g_strjoin(G_DIR_SEPARATOR_S,project.basedir,project.source_directory,NULL);
        /* perhaps check that the directory really is a subdir of the project directory? */
        DEBUG_p("creating %s",srcdir);
        g_mkdir_with_parents(srcdir,0777);
    }
    write_interface();
    write_callback();

    if(true == project.output_build_files)
        write_build_files();

    /* close output files */

    return 0;
}
