/*
 * glade2c - convert glade user interfaces to C source
 *
 * Copyright (C) 2009 Magnus Bergman
 *
 * Author: Magnus Bergman <fabel@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef glade2c_h
#define glade2c_h

#include <glib.h>

#include "widgetdb.h"

typedef enum {unknown,false,true} xbool;

typedef struct{
}Window;

typedef struct{
    PropertyInfo* info;
    /** Must NOT be freed if it's of type T_BOOLEAN */
    char* value;
}Property;

typedef struct{
    /** We keep the name instead of looking it up in the widget class since
        It is always passed as a string anyway (and we trust it's a valid
        signal name. */
    char* name;
    char* handler;
    char* object;
    gboolean after;
    gboolean lookup;
}Signal;

typedef struct _Widget Widget;
struct _Widget{
    /* class stuff */
    WidgetInfo* info;

    /* widget stuff */
    char* id;
    GSList* property_list;
    /** List of properties already set (perhaps using the construcor). The
        are kept here so the can be free later */
    GSList* used_property_list;
    GSList* signal_list;

    /* packing stuff */
    char* position;                     /**< The position of this child, used to decide how to pack */
    gboolean even_position;             /**< Is the position of the child even */
    Widget* previous;                   /**< Just used as a property for packing several widgets at once */
    GSList* pack_property_list;
};

void print_version();

#endif /* glade2c_h */
