/*
 * glade2c - convert glade user interfaces to C source
 *
 * Copyright (C) 2009 Magnus Bergman
 *
 * Author: Magnus Bergman <fabel@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <glib.h>
#include <stdlib.h>                     /* exit() */

#include "debug.h"
#include "glade2c.h"
#include "gladep.h"
#include "project.h"



Project project;



static gboolean flag_version;

static gboolean callback_filename(const char* name,const char* value,void* data,GError** error){
    DEBUG_p("value = %s",value);
    if(project.glade_filename){
        g_warning("Only one glade-file can be handled, %s will be ignored.",value);
    }else{
        project.glade_filename = g_strdup(value);
    }
    return TRUE;
}

static GOptionEntry entries[] = {
  {"basedir",         '\0',0,G_OPTION_ARG_STRING,  &project.basedir,"Base directory","DIR"},
  {"project",         'p', 0,G_OPTION_ARG_STRING,  &project.gladep_filename,"Read Glade project file","FILE"},
  {"source-directory",'s', 0,G_OPTION_ARG_STRING,  &project.source_directory,"Directory to write the source to","DIR"},
  {"interface-source",'\0',0,G_OPTION_ARG_STRING,  &project.interface_source_file,"Write the interface source file","FILE"},
  {"interface-header",'\0',0,G_OPTION_ARG_STRING,  &project.interface_header_file,"Write the interface source file","FILE"},
  {"callbacks-header",'\0',0,G_OPTION_ARG_STRING,  &project.callback_header_file,"Write the interface source file","FILE"},
  {"callback-header", '\0',G_OPTION_FLAG_HIDDEN,G_OPTION_ARG_STRING,  &project.callback_header_file,NULL,NULL},
  {"global-widgets",  'G', 0,G_OPTION_ARG_NONE,    &project.global_widgets,"Make all widgets globally available",NULL},
  {"window-widgets",  'W', 0,G_OPTION_ARG_NONE,    &project.window_widgets,"Create one structure with widgets for each window",NULL},
  {"version",         'V', 0,G_OPTION_ARG_NONE,    &flag_version,"Display version information",NULL},
  {G_OPTION_REMAINING,'\0',0,G_OPTION_ARG_CALLBACK,callback_filename,"Filename","GLADE-FILE"},
  {NULL}
};

#if 0
# if 1
static gboolean check_commandline(GError **error_p){
# else
static gboolean callback_post_parse(GOptionContext* context,GOptionGroup *group,void* data,GError **error_p){
# endif
    DEBUG_p("begin");
    for(;;){
        return TRUE;
    }
    DEBUG_p("this failed");
    if(error_p){
        /* FIXME!! set error object */
    }
    return FALSE;
}
#endif

static gboolean project_from_commandline(int* argc,char*** argv){
    GOptionContext* context;
    GError* error;

    context = g_option_context_new(NULL);
    g_option_context_add_main_entries(context,entries,NULL);
    /* g_option_group_set_parse_hooks(g_option_context_get_main_group(context),NULL,callback_post_parse); */
    /* g_option_context_add_group (context, gtk_get_option_group (TRUE)); */
    if(!g_option_context_parse(context,argc,argv,&error)){
        DEBUG_p("Error parsing cammandline");
        return FALSE;
    }
    return TRUE;
}

/**
  This function plays dirty. Instead of copying the strings it references to
  static strings, assuming project object will not be cleaned up later.
*/
static int project_from_defaults(){
    if(!project.source_directory)
        project.source_directory = "src";
    if(!project.pixmaps_directory)
        project.pixmaps_directory = "pixmaps";
    if(!project.gnome_support)
        project.gnome_support = false;
    if(!project.gettext_support)
        project.gettext_support = true;
    if(!project.use_widget_name)
        project.use_widget_name = false;
    if(!project.output_main_file)
        project.output_main_file = true;
    if(!project.output_support_files)
        project.output_support_files = true;
    if(!project.output_build_files)
        project.output_build_files = true;
    if(!project.backup_source_files)
        project.backup_source_files = true;
    if(!project.gnome_help_support)
        project.gnome_help_support = false;
    if(!project.interface_source_file)
        project.interface_source_file = "interface.c";
    if(!project.interface_header_file)
        project.interface_header_file = "interface.h";
    if(!project.callback_source_file)
        project.callback_source_file = "callbacks.c";
    if(!project.callback_header_file)
        project.callback_header_file = "callbacks.h";
    if(!project.support_source_file)
        project.support_source_file = "support.c";
    if(!project.support_header_file)
        project.support_header_file = "support.h";
    if(!project.output_translatable_strings)
        project.output_translatable_strings = false;
    if(!project.translatable_strings_file)
        project.translatable_strings_file = "";
    return 0;
}

gboolean read_config(int* argc,char*** argv){
    /* first read the commandline */
    if(!project_from_commandline(argc,argv)){
        g_printerr("Invalid option at the command line. Use --help for available options.\n");
        exit(1);
    }
    if(flag_version){
        print_version();
        exit(0);
    }
    if(!project.glade_filename){
        g_printerr("You must specify one glade-file.\n");
        /* FIXME!! print short usage message */
        exit(1);
    }
    project.basedir = g_path_get_dirname(project.glade_filename);

    project.custom_interface_source = project.interface_source_file != NULL;
    project.custom_interface_header = project.interface_header_file != NULL;
    project.custom_callback_header = project.callback_header_file != NULL;

    if(!project.custom_interface_source && !project.custom_interface_header && !project.custom_callback_header){
        project.project_mode = TRUE;
    }

    /* Now we need to read the project file if:
         project_mode = TRUE or
         (custom_interface_source and not custom_callback_header)
    */

    /* then read the projectfile (if anything was missing from the commandline) */
    if(project.gladep_filename){
        if(!parse_gladep()){
            g_printerr("Error reading %s.\n",project.glade_filename);
            exit(1);
        }
    }else{
        char* filename;
        filename = g_strconcat(project.glade_filename,"p",NULL);
        if(g_file_test(filename,G_FILE_TEST_IS_REGULAR)){
            project.gladep_filename = filename;
            /* Errors will be ignored since this file was never guaranteed to exist anyway. */
            parse_gladep();
        }
    }


    /* then set default values (if something is still missing) */
    project_from_defaults();
    return TRUE;
}
