/*
 * glade2c - convert glade user interfaces to C source
 *
 * Copyright (C) 2009 Magnus Bergman
 *
 * Author: Magnus Bergman <fabel@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef read_config_h
#define read_config_h

#include <glib.h>

typedef struct{
    /* main options */
    char* basedir;
    char* gladep_filename;
    char* glade_filename;

    /* options which can be contained in a glade-file */
    char* name;
    char* program_name;
    char* source_directory;             /**< default = "src" */
    char* pixmaps_directory;            /**< default = "pixmaps" */
    xbool gnome_support;                /**< default = no */
    xbool gettext_support;              /**< default = yes */
    xbool use_widget_name;              /**< default = no */
    xbool output_main_file;             /**< default = yes */
    xbool output_support_files;         /**< default = yes */
    xbool output_build_files;           /**< default = yes */
    xbool backup_source_files;          /**< default = yes */
    xbool gnome_help_support;           /**< deafult = no */
    char* interface_source_file;        /**< default = "interface.c" */
    char* interface_header_file;        /**< default = "interface.h" */
    char* callback_source_file;         /**< default = "callbacks.c" */
    char* callback_header_file;         /**< default = "callbacks.h" */
    char* support_source_file;          /**< default = "support.c" */
    char* support_header_file;          /**< default = "support.h" */
    xbool output_translatable_strings;  /**< default = no */
    char* translatable_strings_file;    /**< default = "" */

    /* extended options */
    gboolean custom_interface_source;
    gboolean custom_interface_header;
    gboolean custom_callback_header;
    gboolean project_mode;
    gboolean global_widgets;
    gboolean window_widgets;
    /* xbool dynamic_widgets; */

    /* project internal state */
    int interface_source_fd;
    int interface_header_fd;
    GHashTable* callback_list;
}Project;

extern Project project;

gboolean read_config(int* argc,char*** argv);

#endif /* read_config_h */
