/*
 * glade2c - convert glade user interfaces to C source
 *
 * Copyright (C) 2009 Magnus Bergman
 *
 * Author: Magnus Bergman <fabel@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#undef DEBUG

#include <glib.h>
#include <string.h>                     /* memcpy(), memmove() */

#include "debug.h"

GSList* template_build(char* s,char start,char end){
    char* head;
    char* tail;
    char* out;
    GSList* list;

    DEBUG_p("initial string: %s",s);
    head = out = s;
    list = NULL;
    for(;;){
        DEBUG_p("searching for %c",start);
        for(tail=head;*head && *head!=start;++head);
        DEBUG_p("tail = '%c', head = '%c'",*tail,*head);
        if(head>tail){
            DEBUG_p("adding litteral chunk of size %i",head-tail);
            /* chunk->length = head-tail; */
            /* chunk->text = g_strndup(tail,chunk->length); */
            if(out<tail)
                memmove(out,tail,head-tail);
            out += head-tail;
        }
        if(!*head)
            break;
        ++head; /* skip the start-char */

        DEBUG_p("searching for %c",end);
        for(tail=head;*head && *head!=end;++head);
        if(head>tail){
            list = g_slist_append(list,g_strndup(tail,head-tail));
            /* this is safe since start_char+end_char is 2 bytes even if the
               field happens to be empty (but we know it contains at least
               one char anyway). */
            memcpy(out,"%s",2);
            out += 2;
            DEBUG_p("margin %i",head-out);
        }
        if(!*head){
            /* warning: template ends in a field-name */
            break;
        }
        ++head; /* skip the end-char */
    }
    *out = '\0';
    DEBUG_p("wasting %i bytes",head-out);
    DEBUG_p("resulting string: %s",s);
    return list;
}
